<template>
  <div class="dialog-table-container">
    <el-row :gutter="12">
      <el-col :span="4">
        <div class="search-label">成效形式：</div>
        <dict-select @select="(val, obj) => search(val, 'effect_Form_')" class="quarter-selectop" dictCode="hkdxs"
          :hasDefaultOption="true" clearable v-model="searchData['e.effect_Form_']" style="width: 100%"
          placeholder="请选择成效形式" />
      </el-col>
      <el-col :span="4">
        <div class="search-label">具体情形：</div>
        <el-select @change="val => search(val, 'specific_Details_')" class="quarter-selectop"
          v-model="searchData['e.specific_Details_']" style="width: 100%" clearable placeholder="请选择具体情形">
          <el-option v-for="item in specificSituationOptions" :key="item.value" :label="item.name" :value="item.value">
          </el-option>
        </el-select>
      </el-col>
    </el-row>
    <div class="sub-page-inner">
      <div class="sub-table-container">
        <el-table :element-loading-background="loadingColor" v-loading="loading" ref="dataTable"
          height="calc(100% - 20px)" highlight-current-row current-row-key="id" align="center" :data="tableData"
          class="dialog_table" :cell-style="{ 'text-align': 'center' }" :header-cell-style="{ 'text-align': 'center' }"
          @current-change="currentChange" row-key="id">
          <el-table-column prop="effectTopic" label="改革事项">
          </el-table-column>
          <el-table-column prop="effectForm" label="成效形式" sortable>
            <template slot-scope="props">
              {{ getDictName('cxxs', props.row.effectForm) }}
            </template>
          </el-table-column>
          <el-table-column prop="specificDetails" label="具体情形" sortable>
            <template slot-scope="props">
              {{
                getSubDictName(
                  'cxxs',
                  'cxxs-jtqx',
                  props.row.effectForm,
                  props.row.specificDetails
                )
              }}
            </template>
          </el-table-column>
        </el-table>
      </div>
      <div class="sub-page-detail">
        <div class="bg-de">
          <div class="de-con">
            <div>
              <img v-for="(item, index) in 2" :key="index" src="@/assets/img/bigScreen/img_wk_zs2@2x.png" />
            </div>
            <div class="title">{{ currentRow.effectTopic }}</div>
            <div>
              <img v-for="(item, index) in 2" :key="index" src="@/assets/img/bigScreen/img_wk_zs2@2x.png" />
            </div>
          </div>
        </div>
        <el-form label-position="top" class="sub-page--expand" :element-loading-background="loadingColor"
          v-loading="loading">
          <el-row :gutter="10">
            <el-col :span="8">
              <el-form-item label="成效形式：">
                <span>{{ getDictName('cxxs', currentRow.effectForm) }}</span>
              </el-form-item>
            </el-col>
            <el-col :span="16">
              <el-form-item label="具体情形：">
                <span>
                  {{
                    getSubDictName(
                      'cxxs',
                      'cxxs-jtqx',
                      currentRow.effectForm,
                      currentRow.specificDetails
                    )
                  }}</span>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row>
            <el-form-item label="解决问题：">
              <span>{{ currentRow.solveProblem }}</span>
            </el-form-item>
          </el-row>
          <el-row>
            <el-form-item label="取得成效：">
              <span>{{ currentRow.result }}</span>
            </el-form-item>
          </el-row>
          <el-row>
            <el-form-item label="佐证材料：">
              <el-row v-if="currentRow.fileList">
                <el-col :span="8" v-for="(file, index) in currentRow.fileList" :key="index">
                  <div class="file-style">
                    <div class="file-item">
                      <span class="file-name" :title="file.name
                          ? file.name
                          : file.fileName + '.' + file.extensionName
                        ">{{
    file.name
    ? file.name
    : file.fileName + '.' + file.extensionName
  }}</span>
                      <span class="file-btn short">
                        <el-link type="primary" :underline="false" @click="handlePreview(file)"
                          style="color: #fff">预览</el-link>
                        <el-link type="primary" :underline="false" style="color: #fff"
                          @click="handleDownloadFile(file)">下载</el-link>
                      </span>
                    </div>
                  </div>
                </el-col>
              </el-row>
            </el-form-item>
          </el-row>
        </el-form>
      </div>
      <filePreview ref="filePreview" :appendToBody="true"></filePreview>
    </div>
  </div>
</template>

<script>
import pagenation from './pagenation.vue'
import filePreview from '@/components/FilePreview/filePreview.vue'
import apiList from '@/api/bigScreen/districView.js'
import utils from '@/utils.js'
const portal = window.context.portal
export default {
  name: 'brandDetail',
  components: {
    filePreview,
    pagenation
  },
  props: {
    options: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      searchData: {},
      specificSituationOptions: [],
      loadingColor: 'rgba(6, 46, 106, 0.4)',
      loading: false,
      previewUrl: `${portal}/file/onlinePreviewController/v1/getFileById_`,
      tableData: [],
      currentRow: {},
      code: '',
      paramsFile: {
        pageBean: {
          page: 1,
          pageSize: -1,
          showTotal: true
        },
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'BIZ_ID_',
            relation: 'AND',
            value: ''
          }
        ]
      },
      paramsData: {
        pageBean: {
          page: 1,
          pageSize: 20,
          showTotal: true
        },
        querys: [
          {
            group: 'main',
            operation: 'IN',
            parentGroup: '',
            property: 'e.effect_Form_',
            relation: 'AND',
            value: [1,2]
          },
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'e.specific_Details_',
            relation: 'AND',
            value: ''
          }
        ]
      }
    }
  },
  mounted() {
    this.getSpecificSituationOptions(1)
    this.poliyComp()
    this.$bus.$on('changeDate', () => {
      this.loadData()
    })
  },
  methods: {
    search(e, type) {
      if (type == 'effect_Form_') {
        this.getSpecificSituationOptions(e)
        this.paramsData.querys[0].value = this.searchData['e.effect_Form_'] || [1,2]
        this.searchData['e.specific_Details_'] = ''
      } else if (type == 'specific_Details_') {

      }
      this.paramsData.querys[1].value = this.searchData['e.specific_Details_']
      this.poliyComp()
    },
    poliyComp() {
      let { type, code } = this.$route.query
      if (type) {
        this.$set(this.searchData, 'e.effect_Form_', type + '')
        this.paramsData.querys[0].value = type + ''
        this.getSpecificSituationOptions(type)
      }
      this.code = code
      this.loadData()
    },
    loadData() {
      this.loading = true
      let searchDate = sessionStorage.getItem('searchDate')
      searchDate = JSON.parse(searchDate)
      let data = {
        year: searchDate.year,
        quarter: searchDate.quarter,
        unitCode: this.code
      }
      apiList.getBrandDetail(data, this.paramsData).then(res => {
        console.log(res)
        if (res && res.value) {
          this.tableData = res.value
          if (this.tableData.length) {
            this.currentRow = this.tableData[0]
            this.$nextTick(() => {
              if (this.$refs.dataTable) {
                this.$refs.dataTable.setCurrentRow(this.$refs.dataTable.data[0])
              }
            })
          } else {
            this.currentRow = {}
          }
        }
        this.loading = false
      })
    },
    currentChange(currentRow) {
      console.log(1233)
      this.getFiles(currentRow)
      this.currentRow = currentRow
    },
    getFiles(row) {
      this.paramsFile.querys[0].value = row.id
      apiList.getFiles(this.paramsFile, data => {
        this.currentRow.fileList = data.rows
        this.$forceUpdate()
      })
    },
    handlePreview(file) {
      let id = file.fileId
        ? file.fileId
        : file.id
          ? file.id
          : file.response.fileId
      let type = file.fileType || (file.extensionName
        ? file.extensionName
        : file.name.split('.')[1])
      this.$refs.filePreview.previewUrl = this.previewUrl + id
      this.$refs.filePreview.open(type)
    },
    // 文件下载
    handleDownloadFile(file) {
      console.log(file)
      let id = file.fileId
        ? file.fileId
        : file.id
          ? file.id
          : file.response.fileId
      window.open(portal + `/file/v1/downloadFile?fileId=${id}`, '_self')
    },
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    getSubDictName(code, subCode, value, subValue) {
      let dict = utils.getDictItemsFromCache(code)
      let name = ''
      dict.forEach(item => {
        if (item.value == value) {
          item.lowerDic[subCode].forEach(sub => {
            if (sub.value == subValue) {
              name = sub.name
            }
          })
        }
      })
      return name
    },
    // 根据成效形式获取具体情形列表
    getSpecificSituationOptions(val) {
      let arr = utils.getDictItemsFromCache('hkdxs')
      arr.forEach(item => {
        if (item.value == val) {
          this.specificSituationOptions = item.lowerDic['cxxs-jtqx']
        }
      })
      console.log(this.specificSituationOptions);
    }
  }
}
</script>
<style lang="scss" scoped>
/deep/.el-link--inner {
  color: #fff;
  font-size: 18px;

  &:hover {
    color: #245cf3;
  }
}

/deep/.el-collapse {
  border: none;
}

/deep/.el-collapse-item__wrap {
  background: transparent;
  border: none;
}

/deep/.el-descriptions .is-bordered .el-descriptions-item__cell {
  border-color: #245cf3;
  background: transparent;
  color: #fff;
  font-size: 18px;
}

/deep/.el-table td.el-table__cell div {
  background: transparent;
}

/deep/.dialog_table.el-table tr:nth-of-type(2n + 1) {
  background: transparent;
}

/deep/.el-descriptions__body {
  background: transparent;
}

/deep/.el-collapse-item__header.is-active {
  border-bottom-color: transparent;
  background: transparent;
  color: #245cf3;
  font-size: 20px;
  font-weight: bold;
}

/deep/.el-collapse-item__header {
  background: transparent;
  color: #245cf3;
  font-size: 20px;
  font-weight: bold;
  border: none;
}

/deep/.el-collapse-item__arrow {
  margin: 0;
  font-weight: bold;
}

/deep/.dialog-table-expand label {
  width: 120px;
  color: #fff;
  font-family: SimHei;
}

/deep/ .qx-tag {
  margin: 2px;
  cursor: pointer;
}

/deep/ .el-input__inner {
  background-color: rgba(1, 47, 115, 0.6);
  border: 1px solid #0273e9;
  color: #fff;
}

.search-label {
  color: #fff;
  margin-bottom: 10px;
  font-size: 18px;
}

/deep/ .el-date-editor .el-range-input {
  background-color: rgba(1, 47, 115, 0.6);
  color: #fff;
}

/deep/ .el-date-editor .el-range-separator {
  color: #fff;
}

// /deep/.el-col-8 {
//     width: 100%;
// }
.sub-page-inner {
  height: calc(100% - 60px);
}

.file-item {
  display: flex;
  justify-content: space-between;
  width: 100%;
  padding: 2px 10px;
  padding-right: 5px;
  border-radius: 2px;

  a {
    margin-right: 8px;
    user-select: none;
  }

  .file-name {
    width: calc(100% - 80px);
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
  }

  .file-btn {
    display: inline-block;
    width: 140px;
  }

  .file-btn.short {
    width: 90px;
  }
}

.file-item:hover {
  background-color: rgba(1, 33, 90, 0.6);
}
</style>
<style lang="scss">
@import './table.scss';
</style>
